@@ -26,14 +26,15 @@
 #include <utility>
 #include <vector>
 
-#include "hipfft.h"
+#include "hipfft/hipfft.h"
 
 #include "../hipfft_params.h"
-#include "../rocFFT/clients/tests/fftw_transform.h"
-#include "../rocFFT/clients/tests/rocfft_accuracy_test.h"
-#include "../rocFFT/clients/tests/rocfft_against_fftw.h"
-#include "../rocFFT/shared/gpubuf.h"
-#include "../rocFFT/shared/rocfft_complex.h"
+
+#include "../../shared/accuracy_test.h"
+#include "../../shared/fftw_transform.h"
+#include "../../shared/gpubuf.h"
+#include "../../shared/rocfft_against_fftw.h"
+#include "../../shared/rocfft_complex.h"
 
 void fft_vs_reference(hipfft_params& params, bool round_trip)
 {
@@ -67,8 +68,24 @@ TEST_P(accuracy_test, vs_fftw)
         GTEST_SKIP();
     }
 
+    // only do round trip for single-GPU FFTs
+    bool round_trip = params.multiGPU <= 1;
+
     if(!params.run_callbacks)
-        fft_vs_reference(params, true);
+    {
+        try
+        {
+            fft_vs_reference(params, round_trip);
+        }
+        catch(ROCFFT_GTEST_SKIP& e)
+        {
+            GTEST_SKIP() << e.msg.str();
+        }
+        catch(ROCFFT_GTEST_FAIL& e)
+        {
+            GTEST_FAIL() << e.msg.str();
+        }
+    }
 
     SUCCEED();
 }
